{
    "$graph": [
        {
            "arguments": [],
            "baseCommand": [
                "python",
                "-m",
                "app"
            ],
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "ghcr.io/terradue/ogc-eo-application-package-hands-on/crop:1.3.2",
                    "class": "DockerRequirement"
                }
            ],
            "id": "#crop",
            "inputs": [
                {
                    "inputBinding": {
                        "prefix": "--aoi"
                    },
                    "type": "string",
                    "id": "#crop/aoi"
                },
                {
                    "inputBinding": {
                        "prefix": "--band"
                    },
                    "type": "string",
                    "id": "#crop/band"
                },
                {
                    "inputBinding": {
                        "prefix": "--epsg"
                    },
                    "type": "string",
                    "id": "#crop/epsg"
                },
                {
                    "inputBinding": {
                        "prefix": "--input-item"
                    },
                    "type": "Directory",
                    "id": "#crop/item"
                }
            ],
            "requirements": [
                {
                    "envDef": [
                        {
                            "envValue": "/srv/conda/envs/env_crop/bin:/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin",
                            "envName": "PATH"
                        },
                        {
                            "envValue": "/srv/conda/envs/env_crop/share/proj/",
                            "envName": "PROJ_LIB"
                        },
                        {
                            "envValue": "/workspaces/ogc-eo-application-package-hands-on/water-bodies/command-line-tools/crop:/home/jovyan/ogc-eo-application-package-hands-on/water-bodies/command-line-tools/crop:/home/jovyan/water-bodies/command-line-tools/crop:/workspaces/vscode-binder/command-line-tools/crop",
                            "envName": "PYTHONPATH"
                        }
                    ],
                    "class": "EnvVarRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 2,
                    "ramMax": 2028,
                    "class": "ResourceRequirement"
                }
            ],
            "outputs": [
                {
                    "outputBinding": {
                        "glob": "*.tif"
                    },
                    "type": "File",
                    "id": "#crop/cropped"
                }
            ]
        },
        {
            "class": "Workflow",
            "doc": "Water body detection based on NDWI and otsu threshold",
            "id": "#detect_water_body",
            "inputs": [
                {
                    "doc": "area of interest as a bounding box",
                    "type": "string",
                    "id": "#detect_water_body/aoi"
                },
                {
                    "doc": "bands used for the NDWI",
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#detect_water_body/bands"
                },
                {
                    "default": "EPSG:4326",
                    "doc": "EPSG code",
                    "type": "string",
                    "id": "#detect_water_body/epsg"
                },
                {
                    "doc": "staged STAC item",
                    "type": "Directory",
                    "id": "#detect_water_body/item"
                }
            ],
            "label": "Water body detection based on NDWI and otsu threshold",
            "outputs": [
                {
                    "id": "#detect_water_body/detected_water_body",
                    "outputSource": [
                        "#detect_water_body/node_otsu/binary_mask_item"
                    ],
                    "type": "File"
                }
            ],
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "steps": [
                {
                    "in": [
                        {
                            "source": "#detect_water_body/aoi",
                            "id": "#detect_water_body/node_crop/aoi"
                        },
                        {
                            "source": "#detect_water_body/bands",
                            "id": "#detect_water_body/node_crop/band"
                        },
                        {
                            "source": "#detect_water_body/epsg",
                            "id": "#detect_water_body/node_crop/epsg"
                        },
                        {
                            "source": "#detect_water_body/item",
                            "id": "#detect_water_body/node_crop/item"
                        }
                    ],
                    "out": [
                        "#detect_water_body/node_crop/cropped"
                    ],
                    "run": "#crop",
                    "scatter": "#detect_water_body/node_crop/band",
                    "scatterMethod": "dotproduct",
                    "id": "#detect_water_body/node_crop"
                },
                {
                    "in": [
                        {
                            "source": "#detect_water_body/node_crop/cropped",
                            "id": "#detect_water_body/node_normalized_difference/rasters"
                        }
                    ],
                    "out": [
                        "#detect_water_body/node_normalized_difference/ndwi"
                    ],
                    "run": "#norm_diff",
                    "id": "#detect_water_body/node_normalized_difference"
                },
                {
                    "in": [
                        {
                            "source": "#detect_water_body/node_normalized_difference/ndwi",
                            "id": "#detect_water_body/node_otsu/raster"
                        }
                    ],
                    "out": [
                        "#detect_water_body/node_otsu/binary_mask_item"
                    ],
                    "run": "#otsu",
                    "id": "#detect_water_body/node_otsu"
                }
            ]
        },
        {
            "class": "Workflow",
            "doc": "Main stage manager",
            "id": "#main",
            "inputs": [
                {
                    "doc": "area of interest as a bounding box",
                    "id": "#main/aoi",
                    "label": "area of interest",
                    "type": "string"
                },
                {
                    "type": "string",
                    "id": "#main/aws_access_key_id"
                },
                {
                    "type": "string",
                    "id": "#main/aws_secret_access_key"
                },
                {
                    "default": [
                        "green",
                        "nir"
                    ],
                    "doc": "bands used for the NDWI",
                    "id": "#main/bands",
                    "label": "bands used for the NDWI",
                    "type": {
                        "type": "array",
                        "items": "string"
                    }
                },
                {
                    "type": "string",
                    "id": "#main/endpoint_url"
                },
                {
                    "default": "EPSG:4326",
                    "doc": "EPSG code",
                    "id": "#main/epsg",
                    "label": "EPSG code",
                    "type": "string"
                },
                {
                    "type": "string",
                    "id": "#main/region_name"
                },
                {
                    "type": "string",
                    "id": "#main/s3_bucket"
                },
                {
                    "doc": "list of staged Sentinel-2 COG STAC items",
                    "id": "#main/stac_items",
                    "label": "Sentinel-2 STAC items",
                    "type": {
                        "type": "array",
                        "items": "string"
                    }
                },
                {
                    "type": "string",
                    "id": "#main/sub_path"
                }
            ],
            "label": "macro-cwl",
            "outputs": [
                {
                    "id": "#main/s3_catalog_output",
                    "outputSource": [
                        "#main/node_stage_out/s3_catalog_output"
                    ],
                    "type": "string"
                },
                {
                    "outputSource": [
                        "#main/node_stage_out/stac_catalog_out"
                    ],
                    "type": "Directory",
                    "id": "#main/stac_catalog"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "steps": [
                {
                    "in": [
                        {
                            "source": "#main/stac_items",
                            "id": "#main/node_stage_in/input"
                        }
                    ],
                    "out": [
                        "#main/node_stage_in/stac_items_out"
                    ],
                    "run": {
                        "arguments": [
                            "$( inputs.input )"
                        ],
                        "baseCommand": [
                            "python",
                            "stage.py"
                        ],
                        "class": "CommandLineTool",
                        "cwlVersion": "v1.0",
                        "id": "#main/node_stage_in/stage",
                        "inputs": [
                            {
                                "type": [
                                    "null",
                                    "string"
                                ],
                                "id": "#main/node_stage_in/stage/input"
                            }
                        ],
                        "outputs": [
                            {
                                "outputBinding": {
                                    "glob": "."
                                },
                                "type": "Directory",
                                "id": "#main/node_stage_in/stage/stac_items_out"
                            }
                        ],
                        "requirements": [
                            {
                                "dockerPull": "ghcr.io/terradue/ogc-eo-application-package-hands-on/stage:1.3.2",
                                "class": "DockerRequirement"
                            },
                            {
                                "envDef": [
                                    {
                                        "envValue": "2",
                                        "envName": "A"
                                    }
                                ],
                                "class": "EnvVarRequirement"
                            },
                            {
                                "listing": [
                                    {
                                        "entry": "import pystac\nimport stac_asset\nimport asyncio\nimport os\nimport sys\n\nconfig = stac_asset.Config(warn=True)\nasync def main(href: str):\n    item = pystac.read_file(href)\n    os.makedirs(item.id, exist_ok=True)\n    cwd = os.getcwd()\n    os.chdir(item.id)\n    item = await stac_asset.download_item(item=item, directory=\".\", config=config)\n    os.chdir(cwd)  \n    cat = pystac.Catalog(id=\"catalog\",\n            description=f\"catalog with staged {item.id}\",\n            title=f\"catalog with staged {item.id}\",)\n    cat.add_item(item)\n    cat.normalize_hrefs(\"./\")\n    cat.save(catalog_type=pystac.CatalogType.SELF_CONTAINED)\n    return cat\n    \nhref = sys.argv[1]\ncat = asyncio.run(main(href))",
                                        "entryname": "stage.py"
                                    }
                                ],
                                "class": "InitialWorkDirRequirement"
                            },
                            {
                                "class": "InlineJavascriptRequirement"
                            }
                        ]
                    },
                    "scatter": "#main/node_stage_in/input",
                    "scatterMethod": "dotproduct",
                    "id": "#main/node_stage_in"
                },
                {
                    "in": [
                        {
                            "source": "#main/aws_access_key_id",
                            "id": "#main/node_stage_out/aws_access_key_id"
                        },
                        {
                            "source": "#main/aws_secret_access_key",
                            "id": "#main/node_stage_out/aws_secret_access_key"
                        },
                        {
                            "source": "#main/endpoint_url",
                            "id": "#main/node_stage_out/endpoint_url"
                        },
                        {
                            "source": "#main/region_name",
                            "id": "#main/node_stage_out/region_name"
                        },
                        {
                            "source": "#main/s3_bucket",
                            "id": "#main/node_stage_out/s3_bucket"
                        },
                        {
                            "source": "#main/sub_path",
                            "id": "#main/node_stage_out/sub_path"
                        },
                        {
                            "source": "#main/on_stage/stac_catalog",
                            "id": "#main/node_stage_out/wf_outputs"
                        }
                    ],
                    "out": [
                        "#main/node_stage_out/s3_catalog_output",
                        "#main/node_stage_out/stac_catalog_out"
                    ],
                    "run": {
                        "arguments": [
                            "$( inputs.wf_outputs.path )",
                            "$( inputs.s3_bucket )",
                            "$( inputs.sub_path )"
                        ],
                        "baseCommand": [
                            "python",
                            "stage.py"
                        ],
                        "class": "CommandLineTool",
                        "cwlVersion": "v1.0",
                        "doc": "Stage-out the results to S3",
                        "id": "#main/node_stage_out/stage-out",
                        "inputs": [
                            {
                                "type": "string",
                                "id": "#main/node_stage_out/stage-out/aws_access_key_id"
                            },
                            {
                                "type": "string",
                                "id": "#main/node_stage_out/stage-out/aws_secret_access_key"
                            },
                            {
                                "type": "string",
                                "id": "#main/node_stage_out/stage-out/endpoint_url"
                            },
                            {
                                "type": "string",
                                "id": "#main/node_stage_out/stage-out/region_name"
                            },
                            {
                                "type": "string",
                                "id": "#main/node_stage_out/stage-out/s3_bucket"
                            },
                            {
                                "type": "string",
                                "id": "#main/node_stage_out/stage-out/sub_path"
                            },
                            {
                                "type": "Directory",
                                "id": "#main/node_stage_out/stage-out/wf_outputs"
                            }
                        ],
                        "outputs": [
                            {
                                "outputBinding": {
                                    "outputEval": "${  return \"s3://\" + inputs.s3_bucket + \"/\" + inputs.sub_path + \"/catalog.json\"; }"
                                },
                                "type": "string",
                                "id": "#main/node_stage_out/stage-out/s3_catalog_output"
                            },
                            {
                                "outputBinding": {
                                    "glob": "."
                                },
                                "type": "Directory",
                                "id": "#main/node_stage_out/stage-out/stac_catalog_out"
                            }
                        ],
                        "requirements": [
                            {
                                "dockerPull": "ghcr.io/terradue/ogc-eo-application-package-hands-on/stage:1.3.2",
                                "class": "DockerRequirement"
                            },
                            {
                                "envDef": [
                                    {
                                        "envValue": "$( inputs.aws_access_key_id )",
                                        "envName": "aws_access_key_id"
                                    },
                                    {
                                        "envValue": "$( inputs.endpoint_url )",
                                        "envName": "aws_endpoint_url"
                                    },
                                    {
                                        "envValue": "$( inputs.region_name )",
                                        "envName": "aws_region_name"
                                    },
                                    {
                                        "envValue": "$( inputs.aws_secret_access_key )",
                                        "envName": "aws_secret_access_key"
                                    }
                                ],
                                "class": "EnvVarRequirement"
                            },
                            {
                                "listing": [
                                    {
                                        "entry": "import os\nimport sys\nimport pystac\nimport botocore\nimport boto3\nimport shutil\nfrom pystac.stac_io import DefaultStacIO, StacIO\nfrom urllib.parse import urlparse\n\ncat_url = sys.argv[1]\nbucket = sys.argv[2]\nsubfolder = sys.argv[3]\n\naws_access_key_id = os.environ[\"aws_access_key_id\"]\naws_secret_access_key = os.environ[\"aws_secret_access_key\"]\nregion_name = os.environ[\"aws_region_name\"]\nendpoint_url = os.environ[\"aws_endpoint_url\"]\n\nshutil.copytree(cat_url, \"/tmp/catalog\")\ncat = pystac.read_file(os.path.join(\"/tmp/catalog\", \"catalog.json\"))\n\nclass CustomStacIO(DefaultStacIO):\n    \"\"\"Custom STAC IO class that uses boto3 to read from S3.\"\"\"\n\n    def __init__(self):\n        self.session = botocore.session.Session()\n        self.s3_client = self.session.create_client(\n            service_name=\"s3\",\n            use_ssl=True,\n            aws_access_key_id=aws_access_key_id,\n            aws_secret_access_key=aws_secret_access_key,\n            endpoint_url=endpoint_url,\n            region_name=region_name,\n        )\n\n    def write_text(self, dest, txt, *args, **kwargs):\n        parsed = urlparse(dest)\n        if parsed.scheme == \"s3\":\n            self.s3_client.put_object(\n                Body=txt.encode(\"UTF-8\"),\n                Bucket=parsed.netloc,\n                Key=parsed.path[1:],\n                ContentType=\"application/geo+json\",\n            )\n        else:\n            super().write_text(dest, txt, *args, **kwargs)\n\n\nclient = boto3.client(\n    \"s3\",\n    aws_access_key_id=aws_access_key_id,\n    aws_secret_access_key=aws_secret_access_key,\n    endpoint_url=endpoint_url,\n    region_name=region_name,\n)\n\nStacIO.set_default(CustomStacIO)\n\nfor item in cat.get_items():\n    for key, asset in item.get_assets().items():\n        s3_path = os.path.normpath(\n            os.path.join(os.path.join(subfolder, item.id, asset.href))\n        )\n        print(f\"upload {asset.href} to s3://{bucket}/{s3_path}\",file=sys.stderr)\n        client.upload_file(\n            asset.get_absolute_href(),\n            bucket,\n            s3_path,\n        )\n        asset.href = f\"s3://{bucket}/{s3_path}\"\n        item.add_asset(key, asset)\n\ncat.normalize_hrefs(f\"s3://{bucket}/{subfolder}\")\n\nfor item in cat.get_items():\n    # upload item to S3\n    print(f\"upload {item.id} to s3://{bucket}/{subfolder}\", file=sys.stderr)\n    pystac.write_file(item, item.get_self_href())\n\n# upload catalog to S3\nprint(f\"upload catalog.json to s3://{bucket}/{subfolder}\", file=sys.stderr)\npystac.write_file(cat, cat.get_self_href())\n\nprint(f\"s3://{bucket}/{subfolder}/catalog.json\", file=sys.stdout)",
                                        "entryname": "stage.py"
                                    }
                                ],
                                "class": "InitialWorkDirRequirement"
                            },
                            {
                                "class": "InlineJavascriptRequirement"
                            },
                            {
                                "class": "ResourceRequirement"
                            }
                        ]
                    },
                    "id": "#main/node_stage_out"
                },
                {
                    "in": [
                        {
                            "source": "#main/aoi",
                            "id": "#main/on_stage/aoi"
                        },
                        {
                            "source": "#main/bands",
                            "id": "#main/on_stage/bands"
                        },
                        {
                            "source": "#main/epsg",
                            "id": "#main/on_stage/epsg"
                        },
                        {
                            "source": "#main/node_stage_in/stac_items_out",
                            "id": "#main/on_stage/stac_items"
                        }
                    ],
                    "out": [
                        "#main/on_stage/stac_catalog"
                    ],
                    "run": "#water_bodies",
                    "id": "#main/on_stage"
                }
            ]
        },
        {
            "arguments": [],
            "baseCommand": [
                "python",
                "-m",
                "app"
            ],
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "ghcr.io/terradue/ogc-eo-application-package-hands-on/norm_diff:1.3.2",
                    "class": "DockerRequirement"
                }
            ],
            "id": "#norm_diff",
            "inputs": [
                {
                    "inputBinding": {
                        "position": 1
                    },
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#norm_diff/rasters"
                }
            ],
            "outputs": [
                {
                    "outputBinding": {
                        "glob": "*.tif"
                    },
                    "type": "File",
                    "id": "#norm_diff/ndwi"
                }
            ],
            "requirements": [
                {
                    "envDef": [
                        {
                            "envValue": "/srv/conda/envs/env_norm_diff/bin:/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin",
                            "envName": "PATH"
                        },
                        {
                            "envValue": "/srv/conda/envs/env_norm_diff/share/proj/",
                            "envName": "PROJ_LIB"
                        },
                        {
                            "envValue": "/workspaces/ogc-eo-application-package-hands-on/water-bodies/command-line-tools/norm_diff:/home/jovyan/ogc-eo-application-package-hands-on/water-bodies/command-line-tools/norm_diff:/workspaces/vscode-binder/command-line-tools/norm_diff",
                            "envName": "PYTHONPATH"
                        }
                    ],
                    "class": "EnvVarRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 2,
                    "ramMax": 2028,
                    "class": "ResourceRequirement"
                }
            ]
        },
        {
            "arguments": [],
            "baseCommand": [
                "python",
                "-m",
                "app"
            ],
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "ghcr.io/terradue/ogc-eo-application-package-hands-on/otsu:1.3.2",
                    "class": "DockerRequirement"
                }
            ],
            "id": "#otsu",
            "inputs": [
                {
                    "inputBinding": {
                        "position": 1
                    },
                    "type": "File",
                    "id": "#otsu/raster"
                }
            ],
            "outputs": [
                {
                    "outputBinding": {
                        "glob": "*.tif"
                    },
                    "type": "File",
                    "id": "#otsu/binary_mask_item"
                }
            ],
            "requirements": [
                {
                    "envDef": [
                        {
                            "envValue": "/srv/conda/envs/env_otsu/bin:/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin",
                            "envName": "PATH"
                        },
                        {
                            "envValue": "/srv/conda/envs/env_otsu/share/proj/",
                            "envName": "PROJ_LIB"
                        },
                        {
                            "envValue": "/workspaces/ogc-eo-application-package-hands-on/water-bodies/command-line-tools/otsu:/home/jovyan/ogc-eo-application-package-hands-on/water-bodies/command-line-tools/otsu:/workspaces/vscode-binder/command-line-tools/otsu",
                            "envName": "PYTHONPATH"
                        }
                    ],
                    "class": "EnvVarRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 2,
                    "ramMax": 2028,
                    "class": "ResourceRequirement"
                }
            ]
        },
        {
            "arguments": [],
            "baseCommand": [
                "python",
                "-m",
                "app"
            ],
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "ghcr.io/terradue/ogc-eo-application-package-hands-on/stac:1.3.2",
                    "class": "DockerRequirement"
                }
            ],
            "id": "#stac",
            "inputs": [
                {
                    "type": {
                        "inputBinding": {
                            "prefix": "--input-item"
                        },
                        "items": "Directory",
                        "type": "array"
                    },
                    "id": "#stac/item"
                },
                {
                    "type": {
                        "inputBinding": {
                            "prefix": "--water-body"
                        },
                        "items": "File",
                        "type": "array"
                    },
                    "id": "#stac/rasters"
                }
            ],
            "outputs": [
                {
                    "outputBinding": {
                        "glob": "."
                    },
                    "type": "Directory",
                    "id": "#stac/stac_catalog"
                }
            ],
            "requirements": [
                {
                    "envDef": [
                        {
                            "envValue": "/srv/conda/envs/env_stac/bin:/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin",
                            "envName": "PATH"
                        },
                        {
                            "envValue": "/srv/conda/envs/env_stac/lib/python3.9/site-packages/rasterio/proj_data",
                            "envName": "PROJ_LIB"
                        },
                        {
                            "envValue": "/workspaces/ogc-eo-application-package-hands-on/water-bodies/command-line-tools/stac:/home/jovyan/ogc-eo-application-package-hands-on/water-bodies/command-line-tools/stac:/workspaces/vscode-binder/command-line-tools/stac",
                            "envName": "PYTHONPATH"
                        }
                    ],
                    "class": "EnvVarRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 2,
                    "ramMax": 2028,
                    "class": "ResourceRequirement"
                }
            ]
        },
        {
            "class": "Workflow",
            "doc": "Water bodies detection based on NDWI and otsu threshold",
            "id": "#water_bodies",
            "inputs": [
                {
                    "doc": "area of interest as a bounding box",
                    "label": "area of interest",
                    "type": "string",
                    "id": "#water_bodies/aoi"
                },
                {
                    "default": [
                        "green",
                        "nir"
                    ],
                    "doc": "bands used for the NDWI",
                    "label": "bands used for the NDWI",
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#water_bodies/bands"
                },
                {
                    "default": "EPSG:4326",
                    "doc": "EPSG code",
                    "label": "EPSG code",
                    "type": "string",
                    "id": "#water_bodies/epsg"
                },
                {
                    "doc": "list of staged Sentinel-2 COG STAC items",
                    "label": "Sentinel-2 STAC items",
                    "type": {
                        "type": "array",
                        "items": "Directory"
                    },
                    "id": "#water_bodies/stac_items"
                }
            ],
            "label": "Water bodies detection based on NDWI and otsu threshold",
            "outputs": [
                {
                    "id": "#water_bodies/stac_catalog",
                    "outputSource": [
                        "#water_bodies/node_stac/stac_catalog"
                    ],
                    "type": "Directory"
                }
            ],
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "steps": [
                {
                    "in": [
                        {
                            "source": "#water_bodies/stac_items",
                            "id": "#water_bodies/node_stac/item"
                        },
                        {
                            "source": "#water_bodies/node_water_bodies/detected_water_body",
                            "id": "#water_bodies/node_stac/rasters"
                        }
                    ],
                    "out": [
                        "#water_bodies/node_stac/stac_catalog"
                    ],
                    "run": "#stac",
                    "id": "#water_bodies/node_stac"
                },
                {
                    "in": [
                        {
                            "source": "#water_bodies/aoi",
                            "id": "#water_bodies/node_water_bodies/aoi"
                        },
                        {
                            "source": "#water_bodies/bands",
                            "id": "#water_bodies/node_water_bodies/bands"
                        },
                        {
                            "source": "#water_bodies/epsg",
                            "id": "#water_bodies/node_water_bodies/epsg"
                        },
                        {
                            "source": "#water_bodies/stac_items",
                            "id": "#water_bodies/node_water_bodies/item"
                        }
                    ],
                    "out": [
                        "#water_bodies/node_water_bodies/detected_water_body"
                    ],
                    "run": "#detect_water_body",
                    "scatter": "#water_bodies/node_water_bodies/item",
                    "scatterMethod": "dotproduct",
                    "id": "#water_bodies/node_water_bodies"
                }
            ]
        }
    ],
    "cwlVersion": "v1.0",
    "$namespaces": {
        "s": "https://schema.org/"
    }
}
